@@ -2,4 +2,5 @@ from .api.gen import *
 from .api.gen_sync import Client as SyncClient
 from .config import Config as Config
 from .connection import Connection as Connection
-from .exceptions import DaggerError as Error
+from .exceptions import DaggerError as DaggerError
+from .exceptions import ProvisionError as ProvisionError
