@@ -4,7 +4,8 @@ import sys
 import anyio
 import typer
 
-from ..log import configure_logging
+from dagger.log import configure_logging
+
 from . import Server
 
 app = typer.Typer()
@@ -12,23 +13,20 @@ app = typer.Typer()
 
 @app.command()
 def main(
-    schema: bool = typer.Option(False, "-schema", help="Save schema to file and exit")
+    schema: bool = typer.Option(False, "-schema", help="Save schema to file and exit"),
 ):
-    """
-    Entrypoint for a dagger extension.
-    """
-
+    """Entrypoint for a dagger extension."""
     sys.path.insert(0, ".")
 
     try:
-        from main import server  # type: ignore
+        from main import server
     except ImportError as e:
-        raise typer.BadParameter(
-            "No “server: dagger.Server” found in “main” module."
-        ) from e
+        msg = "No “server: dagger.Server” found in “main” module."
+        raise typer.BadParameter(msg) from e
 
     if not isinstance(server, Server):
-        raise typer.BadParameter("The “server” must be an instance of “dagger.Server”")
+        msg = "The “server” must be an instance of “dagger.Server”"
+        raise typer.BadParameter(msg)
 
     configure_logging(logging.DEBUG if server.debug else logging.INFO)
 
